function r = LHSS_test(x_test,lhss_param)
%
% Least-squares Hetero-distributional Subspace Search (LHSS)
%
% Estimating ratio of probability densities
%   \frac{ p_{nu}(x) }{ p_{de}(x) }
% from samples
%    { xde_i | xde_i\in R^{d} }_{i=1}^{n_{de}}
% drawn independently from p_{de}(x) and samples
%    { xnu_i | xnu_i\in R^{d} }_{i=1}^{n_{nu}}
% drawn independently from p_{nu}(x).
%
% Usage:
%       [U_opt PD_opt sigmatopt alphah_opt x_ce optscore] = LHSS_test(x_test, lhss_param)
%
% Input:
%    x_de:          d by n_de sample matrix corresponding to `denominator' (iid from density p_de)
%  lhss_param:      Model parameter computed by LHSS_train().
%
%
% Output:
%   r:              Density ratio
%
% (c) Makoto Yamada, Department of Compter Science, Tokyo Institute of Technology, Japan.
%     yamada@sg.cs.titech.ac.jp,
%     http://sugiyama-www.cs.titech.ac.jp/~sugi/software/D3LHSS/

K_test=kernel_Gaussian(lhss_param.U'*x_test,lhss_param.U'*lhss_param.x_ce,lhss_param.sigma)';
r =(K_test'*lhss_param.alpha)';