% demo_LHSS.m
%
% (c) Makoto Yamada, Department of Compter Science, Tokyo Institute of Technology, Japan.
%     yamada@sg.cs.titech.ac.jp,     http://sugiyama-www.cs.titech.ac.jp/~sugi/software/D3LHSS/

clear all;
close all;

%1: Rather separated data
%2: Highly overlapped data
%3: Dependent data
type = 1;

%Rather separated data
if type == 1
    load sep_data;
    name = 'sep';
    tname = '(Rather Separated)';
end

%Highly overlapped data
if type == 2
    load les_data;
    name = 'les';
    tname = '(Highly overlapped)';
end

%Dependent data
if type == 3
    load dep_data;
    name = 'dep';
    tname = '(Dependent)';
end

nBasis = 100;

%Train LHSS
lhss_param = LHSS_train(x_de, x_nu);

%Compute importance using LHSS
r = LHSS_test(x_de_te,lhss_param);

%Compute the error between true and estimated importances
er = mean((r_te - r).^2)/2;
disp(sprintf('error: %d', er))

% Draw surface of the estimated importance
n = 50;
x = linspace(-6, 6, n);
y = linspace(-6, 6, n);
x1 = repmat(x, [n, 1]);
y1 = repmat(y',[1, n]);
xy = [x1(:)'; y1(:)'];

r_xy = LHSS_test(xy,lhss_param);
z_lhss = reshape(r_xy,[n,n]);

%True subspace
U_true = [1 0];

figure(1);
set(gca,'fontsize',16);
plot(x_de(1,:), x_de(2,:), 'rx', 'MarkerSize',10, 'LineWidth', 0.5); hold on;
plot(x_nu(1,:), x_nu(2,:), 'o', 'MarkerSize', 5,'LineWidth',0.5);
axis([min(x), max(x), min(y), max(y)]);
plot([-U_true(1) U_true(1)]*10,[-U_true(2) U_true(2)]*10,'k:','LineWidth',8);
plot([-lhss_param.U(1) lhss_param.U(1)]*10,[-lhss_param.U(2) lhss_param.U(2)]*10,'k-','LineWidth',2);
hold off;
xlabel('x^{(1)}');
ylabel('x^{(2)}');
legend('x^{de}', 'x^{nu}', 'True Subspace', 'LHSS Subspace', -1);
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0,0,24,12]);
print(sprintf('data_%s',name), '-dpng');
print(sprintf('data_%s',name), '-depsc');


figure(2)
set(gca, 'FontSize', 16);
surf(x, y, z);
axis([min(x), max(x), min(y), max(y), 0, max(max(z)) * 1.1]);
xlabel('x^{(1)}');
ylabel('x^{(2)}');
title(sprintf('True density ratio'));
view(20, 50);
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0, 0, 16, 12]);
print(sprintf('true_%s',name), '-dpng'); %Print figure with png
print(sprintf('true_%s',name), '-depsc');%Print figure with eps


figure(3)
set(gca, 'FontSize', 16);
surf(x, y, z_lhss);
axis([min(x), max(x), min(y), max(y), 0, max(max(z)) * 1.1]);
xlabel('x^{(1)}');
ylabel('x^{(2)}');
title(sprintf('Estimated density ratio'));
view(20, 50);
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0, 0, 16, 12]);
print(sprintf('lhss_%s',name), '-dpng'); %Print figure with png
print(sprintf('lhss_%s',name), '-depsc');%Print figure with eps
